@@ -4,9 +4,10 @@ from .controller import Controller, Descriptor, path
 from .decorators import (get, post, delete, patch, put,
                          before_request, after_request,
                          produces, consumes, open_api_docs,
-                         cors, no_cors)
+                         cors, no_cors, socket, development)
 
 __all__ = ["Controller", "path", "get", "post", "put",
            "patch", "delete", "consumes",
            "produces", "Descriptor", "open_api_docs",
-           "before_request", "after_request", "cors", "no_cors"]
+           "before_request", "after_request", "cors", "no_cors",
+           "socket", "development"]
