@@ -13,8 +13,8 @@ if TYPE_CHECKING:
 T = TypeVar("T", bound="Controller")
 
 def path(url_path: str = "/", open_api_spec: bool = True,
-         tags: Optional[list[str]] = None) -> Callable[[Type[T]], Type[T]]:
-    def decorator(cls: Type[T]) -> Type[T]:
+         tags: Optional[list[str]] = None) -> "Callable":
+    def decorator(cls: "Type[Controller]") -> "Type[Controller]":
         setattr(cls, "_controller_path", url_path)
         setattr(cls, "_include_open_api_spec", open_api_spec)
         setattr(cls, "_open_api_tags", tags)
@@ -24,13 +24,14 @@ def path(url_path: str = "/", open_api_spec: bool = True,
 
 class Controller:
 
+    #_controller_decorator_methods: list[Callable]
+
     def __init__(self, app: "PyJolt", url_path: str = "/", open_api_spec: bool = True, open_api_tags: Optional[list[str]] = None):
         self._app = app
         self._path = url_path
         self._before_request_methods: list[Callable] = []
         self._after_request_methods: list[Callable] = []
-        self._controller_decorator_methods: list[Callable] = []
-        self._endpoints_map: dict[str, dict[str, str|Callable]] = {}
+        self._endpoints_map: dict[str, dict[str, str|Callable|dict]] = {}
         self._open_api_spec = open_api_spec
         self._open_api_tags = open_api_tags if open_api_tags is not None else [self.__class__.__name__]
         self.get_before_request_methods()
@@ -96,7 +97,7 @@ class Controller:
               self._after_request_methods.append(method)
 
     @property
-    def endpoints_map(self) -> dict[str, dict[str, str|Callable]]:
+    def endpoints_map(self) -> dict[str, dict[str, str|Callable|dict]]:
         """Returns map of all endpoints"""
         return self._endpoints_map
 
