@@ -10,7 +10,7 @@ from sqlalchemy.ext.asyncio import AsyncSession
 if TYPE_CHECKING:
     from .sqlalchemy_models import AsyncQuery
 
-class BaseModel:
+class DeclarativeBaseModel:
     """
     Defines the interface that the custom
     DeclarativeBase class must satisfy.
