@@ -39,7 +39,7 @@ from .controller import Controller
 from .exceptions import ExceptionHandler
 from .base_extension import BaseExtension
 from .configuration_base import BaseConfig
-from .database.sql.base_protocol import BaseModel as BaseModelClass
+from .database.sql.base_protocol import DeclarativeBaseModel as BaseModelClass
 from .middleware import MiddlewareBase, AppCallableType
 from .cli import CLIController
 from .logging.logger_config_base import LoggerBase
@@ -63,7 +63,7 @@ try:
         # now call the real ASGI loop
         return await _orig_run_asgi(self, application)
 
-    RequestResponseCycle.run_asgi = _patched_run_asgi
+    RequestResponseCycle.run_asgi = _patched_run_asgi #type: ignore[method-assign]
 # pylint: disable-next=W0718
 except Exception as e:
     logger.debug(
@@ -145,16 +145,16 @@ class WrongModuleLoadType(Exception):
         super().__init__(msg)
 
 
-def validate_config(config_obj_or_type: Type[BaseConfig]) -> BaseConfig:
+def validate_config(config_obj_or_type: Type[BaseConfig]|BaseConfig) -> BaseConfig:
     # If it's already an instance
     if isinstance(config_obj_or_type, BaseConfig):
-        return config_obj_or_type  # already validated by Pydantic
+        return cast(BaseConfig, config_obj_or_type)  # already validated by Pydantic
 
     if inspect.isclass(config_obj_or_type) and issubclass(
         config_obj_or_type, BaseConfig
     ):
         try:
-            instance = config_obj_or_type()
+            instance = config_obj_or_type() # type: ignore[call-arg]
         except Exception as e:
             raise MissingAppConfigurations(
                 f"Could not instantiate config class {config_obj_or_type.__name__}: {e}"
@@ -485,7 +485,7 @@ class PyJolt:
         self._log_request(scope, method, url_path)
 
         route_handler, path_kwargs = self.router.match(url_path, method)
-        req = Request(scope, receive, self, path_kwargs, cast(Callable, route_handler))
+        req = self.request_class(scope, receive, self, path_kwargs, cast(Callable, route_handler))
 
         if not route_handler:
             return await self.abort_route_not_found(send, req, path_kwargs)
@@ -638,7 +638,7 @@ class PyJolt:
                     self._add_route_function(
                         http_method,
                         self._app_base_url + ctrl_instance.path + url_path,
-                        method["method"],
+                        cast(Callable, cast(dict, method)["method"]),
                         endpoint_name,
                     )
 
@@ -787,6 +787,22 @@ class PyJolt:
     @property
     def jinja_environment(self) -> Environment:
         return self._jinja_environment
+    
+    @property
+    def request_class(self) -> Type[Request]:
+        """
+        Returns the Request class used by the application.
+        Can be overridden in configs to provide a custom Request subclass.
+        """
+        return self.get_conf("REQUEST_CLASS", Request)
+    
+    @property
+    def response_class(self) -> Type[Response]:
+        """
+        Returns the Response class used by the application.
+        Can be overridden in configs to provide a custom Response subclass.
+        """
+        return self.get_conf("RESPONSE_CLASS", Response)
 
     async def __call__(self, scope, receive, send):
         """
